#
# spec file for package git-next
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-next
Version:        2025.5.0
Release:        1.1
Summary:        Trunk-based development manager for a solo developer
License:        MIT
URL:            https://codeberg.org/kemitix/git-next
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.81
BuildRequires:  cargo-packaging
BuildRequires:  git-core
BuildRequires:  pkgconfig(dbus-1)

%description
Trunk-based developement manager.

git-next is a combined server and command-line tool that enables trunk-based
development workflows where each commit must pass CI before being included in
the main branch.

"A source-control branching model, where developers collaborate on code in a
single branch called ‘trunk’, resist any pressure to create other long-lived
development branches by employing documented techniques. They therefore avoid
merge hell, do not break the build, and live happily ever after."
(https://trunkbaseddevelopment.com/)

Features

* Allows enforcing the requirement for each commit to pass the CI pipeline
  before being included in the main branch
* Provides a server component that manages the trunk-based development process
* Ensure a consistent, high-quality codebase by preventing untested changes
  from being added to main
* Requires each commit uses conventional commit format.

%prep
%autosetup -p 1 -a 1

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%check
git config --global user.email "test@test.test"
git config --global user.name "test"

%{cargo_test}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Wed May  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2025.5.0:
  * Added
  - (gitlib) remove Gix enum variant and gix logic
  - implement git2-based rebase_onto with tests
  - Add tests for git2 remote operations
  - (gitlib) implement switch_branch using git2
  - (gitlib) implement push using git2
  - (gitlib) implement fetch using git2
  - (gitlib) implement read_file using git2 backend
  - (gitlib) implement find_default_remote_url and commit_log
    using git2
  - (gitlib) implement remote_branches using git2
  - (gitlib) implement clone using git2
  - (gitlib) implement open using git2
  - (git) encapsulate gix usage within gitlib module
  - extract non-default feature 'notify-desktop'
  - extract non-default feature 'notify-desktop'
  - rename forgejo and github features with 'forge-' prefix
  - remove 'notify-email' from default features
  - define cargo feature 'notify-email'
  * Fixed
  - remove stray dbg macro
  - use fetch remote if no explicit push remote configured
  - enable https feature in git2 to allow cloning
  * Other
  - remove duplicate --all-features from Dockerfile
  - allow fixes to include dependency changes
  - allow optional scope in commit message regex patterns
  - (ci) enhance workflow safety and performance
  - (gitlib) introduce GitRepository enum for backend abstraction
  - (ci) add OpenSSL build dependencies in Forgejo workflow
  - (ci) update actions/cache usage in Forgejo workflows
  - fix restore key for cargo registry cache
  - add TODO plan to replace gix with git2
  - Add inferred project rules to .dev/RULES.md
  - Update rules to reflect gix's encapsulation within gitlib
  - add project coding rules
  - add coding project coding conventions
  - Add TODO file
  - fix regex pattern for file matching
  - commit path rules allows dev-note updates under the 'docs'
    tag.
  - (workflow,justfile) use cargo check rather than build
  - Delegate git operations to gitlib in RealOpenRepository
  - remove pike dependency
  - add cargo dependency caching to workflow
  - add bon::Builder to prelude
  - add kx_utils::marker to prelude
  - add common tracing uses to prelude
  - introduce prelude to isolate color_eyre
  - rearrange root module declarations
  - consolidate from anyhow onto color_eyre
  - (deps) upgrade kameo from 0.15 to 0.16
* Tue Mar 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 2025.3.4:
  * Fixed
  - clear status to waiting when expire message token received
  - don't send duplicate WebhookReceive updates for next and dev
  - improve error message on unconventional commit
  - (xui) rebase and user intervention handler use selected repo
  * Other
  - (xui) add regresion test for displaying selected repo when
    filtered
  - (xui) DataState widget
  - (xui) extract popup rendering into fn
  - fix flaky test by generating valid test hostnames
  - replace ForgeConfig contructor with Builder
* Sun Mar 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 2025.3.3:
  * Other
  - (push-main-pr) allow manual dispatch of workflow
  - (docker) publish docker image with tag not branch
- Update to version 2025.3.2:
  * Other
  - (push-main-release) fix second typo in tagging codeberg
    images
- Update to version 2025.3.1:
  * Fixed
  - (xui) display correct repo when filtered
  * Other
  - (push-main-release) fix typo in tagging codeberg images
  - (deps) upgrade rstest from 0.24 to 0.25
  - (xui) UserAlert use Builder
  - (push-main-release) don't update PR concurrently
  - (xui) RepoTable and RepoTableItem use Builder
  - drop derive_setters in favour of derive_with
  - reduce how often docker image is built
  - (xui) CommitLog use Builder
  - (xui) UserInputActor use Builder
  - (xui) UiState use Builder
  - (xui) RepoState fields not pub
  - (xui) RepoKey use Builder
  - (xui) RepoDetails use Builder
* Sat Mar 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 2025.3.0:
  * Added
  - always validate repo on valid webhook
  * Documentation
  - fix minor typos in README
  * Other
  - (deps) upgrade kameo from 0.14 to 0.15
  - (deps) upgrade derive_more from 1.0 to 2.0
  - (deps) upgrade rand from 0.8 to 0.9
  - (deps) upgrade derive-with from 0.5 to 0.6
  - add forgejo-commit-path-rules v0.2.3
  - sort dependencies
  - clippy fixes
* Thu Feb 27 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package git-next: trunk-based development manager for a solo
  developer
